.. :changelog:

Release History
---------------

0.2.7 (2018-01-01)
++++++++++++++++++
- Verification added for zipcode value
- Test added for assert on the raise

0.2.6 (2017-12-31)
++++++++++++++++++
- Change the dates in 'HISTORY.rst' to the correct month
- Library also returns a list for multiple dates highlighted on the webpage

0.2.5 (2017-12-28)
++++++++++++++++++
- Improving the python packaging, following: `Python packaging <https://python-packaging.readthedocs.io>`__

0.2.4 (2017-12-27)
++++++++++++++++++
- Fixed rst issues; now showing correct html on pypi
- learned about ``python setup.py checkdocs``; require *pygments* and *collective.checkdocs*

0.2.1 (2017-12-26)
++++++++++++++++++
- Changing the way of working with '__version__'
- Changed versioning scheme
- Removed the datetime dependency
- Rewritten parts and tests to work with python 2.7 and 3.4+
- Rewritten Markdown to restructured text

0.2 (2017-12-25)
++++++++++++++++
- Status Beta
- Versioning in sync, setup reads it from the program
- History (this file) added
- Property decorators instead of traditional getters
- README improved

0.1 (2017-08-24)
++++++++++++++++
**Initial release**
- first working release
- py.tests
- travis-ci
- pypi
- hours of troubleshooting the 2 above
